@@ -15,7 +15,7 @@ from gravitorch.creators.datapipe.base import (
     setup_iter_datapipe_creator,
 )
 from gravitorch.engines.base import BaseEngine
-from gravitorch.utils.format import str_add_indent, to_torch_sequence_str
+from gravitorch.utils.format import str_indent, to_torch_sequence_str
 
 
 class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
@@ -41,7 +41,7 @@ class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
     def __repr__(self) -> str:
         return (
             f"{self.__class__.__qualname__}(\n"
-            f"  {str_add_indent(to_torch_sequence_str(self._config))},\n)"
+            f"  {str_indent(to_torch_sequence_str(self._config))},\n)"
         )
 
     def create(
@@ -74,7 +74,7 @@ class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
             # Create an IterDataPipe object using a single IterDataPipe object and no source input
             >>> creator = SequentialIterDataPipeCreator(
             ...     {
-            ...         OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe",
+            ...         OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper",
             ...         "data": [1, 2, 3, 4],
             ...     }
             ... )
@@ -85,7 +85,7 @@ class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
             >>> creator = SequentialIterDataPipeCreator(
             ...     [
             ...         {
-            ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe",
+            ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper",
             ...             "data": [1, 2, 3, 4],
             ...         },
             ...     ]
@@ -96,7 +96,7 @@ class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
             # It is possible to use the source_inputs to create the same IterDataPipe object.
             # The data is given by the source_inputs
             >>> creator = SequentialIterDataPipeCreator(
-            ...     config={OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe"},
+            ...     config={OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper"},
             ... )
             >>> datapipe: IterDataPipe = creator.create(source_inputs=([1, 2, 3, 4],))
             >>> tuple(datapipe)
@@ -105,7 +105,7 @@ class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
             >>> creator = SequentialIterDataPipeCreator(
             ...     [
             ...         {
-            ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe",
+            ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper",
             ...             "data": [1, 2, 3, 4],
             ...         },
             ...         {
@@ -127,9 +127,9 @@ class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
             ...         },
             ...     ],
             ... )
-            >>> from gravitorch.data.datapipes.iter import SourceIterDataPipe
+            >>> from gravitorch.data.datapipes.iter import SourceWrapper
             >>> datapipe: IterDataPipe = creator.create(
-            ...     source_inputs=[SourceIterDataPipe(data=[1, 2, 3, 4])]
+            ...     source_inputs=[SourceWrapper(data=[1, 2, 3, 4])]
             ... )
             >>> tuple(datapipe)
             ([1, 2], [3, 4])
@@ -146,8 +146,8 @@ class SequentialIterDataPipeCreator(BaseIterDataPipeCreator):
             ... )
             >>> datapipe: IterDataPipe = creator.create(
             ...    source_inputs=[
-            ...         SourceIterDataPipe(data=[1, 2, 3, 4]),
-            ...         SourceIterDataPipe(data=[11, 12, 13, 14]),
+            ...         SourceWrapper(data=[1, 2, 3, 4]),
+            ...         SourceWrapper(data=[11, 12, 13, 14]),
             ...     ],
             ... )
             >>> tuple(datapipe)
@@ -222,7 +222,7 @@ def create_sequential_iter_datapipe(
         # Create an IterDataPipe object using a single IterDataPipe object and no source input
         >>> datapipe: IterDataPipe = create_sequential_iter_datapipe(
         ...     {
-        ...         OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe",
+        ...         OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper",
         ...         "data": [1, 2, 3, 4],
         ...     }
         ... )
@@ -232,7 +232,7 @@ def create_sequential_iter_datapipe(
         >>> datapipe: IterDataPipe = create_sequential_iter_datapipe(
         ...     [
         ...         {
-        ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe",
+        ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper",
         ...             "data": [1, 2, 3, 4],
         ...         },
         ...     ]
@@ -242,7 +242,7 @@ def create_sequential_iter_datapipe(
         # It is possible to use the source_inputs to create the same IterDataPipe object.
         # The data is given by the source_inputs
         >>> datapipe: IterDataPipe = create_sequential_iter_datapipe(
-        ...     config={OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe"},
+        ...     config={OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper"},
         ...     source_inputs=([1, 2, 3, 4],),
         ... )
         >>> tuple(datapipe)
@@ -251,7 +251,7 @@ def create_sequential_iter_datapipe(
         >>> datapipe: IterDataPipe = create_sequential_iter_datapipe(
         ...     [
         ...         {
-        ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe",
+        ...             OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper",
         ...             "data": [1, 2, 3, 4],
         ...         },
         ...         {OBJECT_TARGET: "torch.utils.data.datapipes.iter.Batcher", "batch_size": 2},
@@ -261,12 +261,12 @@ def create_sequential_iter_datapipe(
         ([1, 2], [3, 4])
         # It is possible to use the source_inputs to create the same IterDataPipe object.
         # A source IterDataPipe object is specified by using source_inputs
-        >>> from gravitorch.data.datapipes.iter import SourceIterDataPipe
+        >>> from gravitorch.data.datapipes.iter import SourceWrapper
         >>> datapipe: IterDataPipe = create_sequential_iter_datapipe(
         ...     config=[
         ...         {OBJECT_TARGET: "torch.utils.data.datapipes.iter.Batcher", "batch_size": 2},
         ...     ],
-        ...     source_inputs=[SourceIterDataPipe(data=[1, 2, 3, 4])],
+        ...     source_inputs=[SourceWrapper(data=[1, 2, 3, 4])],
         ... )
         >>> tuple(datapipe)
         ([1, 2], [3, 4])
@@ -278,8 +278,8 @@ def create_sequential_iter_datapipe(
         ...         {OBJECT_TARGET: "torch.utils.data.datapipes.iter.Batcher", "batch_size": 2},
         ...     ],
         ...     source_inputs=[
-        ...         SourceIterDataPipe(data=[1, 2, 3, 4]),
-        ...         SourceIterDataPipe(data=[11, 12, 13, 14]),
+        ...         SourceWrapper(data=[1, 2, 3, 4]),
+        ...         SourceWrapper(data=[11, 12, 13, 14]),
         ...     ],
         ... )
         >>> tuple(datapipe)
@@ -321,7 +321,7 @@ class SequentialCreatorIterDataPipeCreator(BaseIterDataPipeCreator):
     def __repr__(self) -> str:
         return (
             f"{self.__class__.__qualname__}(\n"
-            f"  {str_add_indent(to_torch_sequence_str(self._creators))},\n)"
+            f"  {str_indent(to_torch_sequence_str(self._creators))},\n)"
         )
 
     def create(
@@ -360,7 +360,7 @@ class SequentialCreatorIterDataPipeCreator(BaseIterDataPipeCreator):
             ...     [
             ...         SequentialIterDataPipeCreator(
             ...             {
-            ...                 OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe",
+            ...                 OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper",
             ...                 "data": [1, 2, 3, 4],
             ...             },
             ...         ),
@@ -374,7 +374,7 @@ class SequentialCreatorIterDataPipeCreator(BaseIterDataPipeCreator):
             >>> creator = SequentialCreatorIterDataPipeCreator(
             ...     [
             ...         SequentialIterDataPipeCreator(
-            ...             {OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe"},
+            ...             {OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper"},
             ...         ),
             ...     ]
             ... )
@@ -385,7 +385,7 @@ class SequentialCreatorIterDataPipeCreator(BaseIterDataPipeCreator):
             >>> creator = SequentialCreatorIterDataPipeCreator(
             ...     [
             ...         SequentialIterDataPipeCreator(
-            ...             {OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceIterDataPipe"},
+            ...             {OBJECT_TARGET: "gravitorch.data.datapipes.iter.SourceWrapper"},
             ...         ),
             ...         SequentialIterDataPipeCreator(
             ...             {
@@ -400,7 +400,7 @@ class SequentialCreatorIterDataPipeCreator(BaseIterDataPipeCreator):
             ([1, 2], [3, 4])
             # It is possible to use the source_inputs to create the same IterDataPipe object.
             # A source IterDataPipe object is specified by using source_inputs
-            >>> from gravitorch.data.datapipes.iter import SourceIterDataPipe
+            >>> from gravitorch.data.datapipes.iter import SourceWrapper
             >>> creator = SequentialCreatorIterDataPipeCreator(
             ...     creators=[
             ...         SequentialIterDataPipeCreator(
@@ -412,7 +412,7 @@ class SequentialCreatorIterDataPipeCreator(BaseIterDataPipeCreator):
             ...     ]
             ... )
             >>> datapipe: IterDataPipe = creator.create(
-            ...     source_inputs=[SourceIterDataPipe(data=[1, 2, 3, 4])]
+            ...     source_inputs=[SourceWrapper(data=[1, 2, 3, 4])]
             ... )
             >>> tuple(datapipe)
             ([1, 2], [3, 4])
@@ -433,8 +433,8 @@ class SequentialCreatorIterDataPipeCreator(BaseIterDataPipeCreator):
             ... )
             >>> datapipe: IterDataPipe = creator.create(
             ...    source_inputs=[
-            ...         SourceIterDataPipe(data=[1, 2, 3, 4]),
-            ...         SourceIterDataPipe(data=[11, 12, 13, 14]),
+            ...         SourceWrapper(data=[1, 2, 3, 4]),
+            ...         SourceWrapper(data=[11, 12, 13, 14]),
             ...     ],
             ... )
             >>> tuple(datapipe)
