@@ -43,6 +43,7 @@ __all__ = [
     "ShiftScale",
     "Sin",
     "Sinh",
+    "Snake",
     "SquaredReLU",
     "Squeeze",
     "SumFusion",
@@ -72,14 +73,14 @@ __all__ = [
     "module_mode",
     "num_learnable_parameters",
     "num_parameters",
-    "setup_nn_module",
+    "setup_module",
     "show_parameter_stats",
     "state_dicts_are_equal",
     "top_module_mode",
     "unfreeze_module",
 ]
 
-from gravitorch.nn.activations import ReLUn, SquaredReLU
+from gravitorch.nn.activations import ReLUn, Snake, SquaredReLU
 from gravitorch.nn.alpha_activations import (
     ExpSin,
     Gaussian,
@@ -157,7 +158,7 @@ from gravitorch.nn.utils import (
     module_mode,
     num_learnable_parameters,
     num_parameters,
-    setup_nn_module,
+    setup_module,
     show_parameter_stats,
     state_dicts_are_equal,
     top_module_mode,
