@@ -1,6 +1,5 @@
 __all__ = [
-    "BaseDistributedRunner",
-    "BaseEngineDistributedRunner",
+    "BaseResourceRunner",
     "BaseRunner",
     "EvaluationRunner",
     "NoRepeatRunner",
@@ -10,11 +9,8 @@ __all__ = [
 ]
 
 from gravitorch.runners.base import BaseRunner
-from gravitorch.runners.distributed import (
-    BaseDistributedRunner,
-    BaseEngineDistributedRunner,
-)
 from gravitorch.runners.evaluation import EvaluationRunner
 from gravitorch.runners.no_repeat import NoRepeatRunner
+from gravitorch.runners.resource import BaseResourceRunner
 from gravitorch.runners.training import TrainingRunner
 from gravitorch.runners.utils import configure_pytorch, setup_runner
